Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(391)

Unified Diff: chrome/browser/extensions/api/record/record_api_test.cc

Issue 11778096: Revert 176047 (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: Created 7 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/extensions/api/record/record_api_test.cc
===================================================================
--- chrome/browser/extensions/api/record/record_api_test.cc (revision 176049)
+++ chrome/browser/extensions/api/record/record_api_test.cc (working copy)
@@ -217,13 +217,14 @@
// Run a capture, using standard URL test list and the specified
// user data dir. Return via |out_list| the list of error URLs,
// if any, resulting from the capture. And return directly the
// CaptureURLsFunction that was used, so that its state may be
// queried.
- scoped_refptr<CaptureURLsFunction> RunCapture(const FilePath& user_data_dir,
+ scoped_refptr<RecordCaptureURLsFunction> RunCapture(
+ const FilePath& user_data_dir,
scoped_ptr<base::ListValue>* out_list) {
- scoped_refptr<CaptureURLsFunction> capture_function(
- new CaptureURLsFunction(new TestProcessStrategy(&temp_files_)));
+ scoped_refptr<RecordCaptureURLsFunction> capture_function(
+ new RecordCaptureURLsFunction(new TestProcessStrategy(&temp_files_)));
std::string escaped_user_data_dir;
ReplaceChars(user_data_dir.AsUTF8Unsafe(), "\\", "\\\\",
@@ -277,7 +278,7 @@
scoped_ptr<base::ListValue> result;
EXPECT_TRUE(user_data_dir.CreateUniqueTempDir());
- scoped_refptr<CaptureURLsFunction> capture_URLs_function =
+ scoped_refptr<RecordCaptureURLsFunction> capture_URLs_function =
RunCapture(user_data_dir.path(), &result);
// Check that user-data-dir switch has been properly overridden.
@@ -314,7 +315,8 @@
ReplaceChars(user_data_dir.path().AsUTF8Unsafe(), "\\", "\\\\",
&escaped_user_data_dir);
- scoped_refptr<ReplayURLsFunction> playback_function(new ReplayURLsFunction(
+ scoped_refptr<RecordReplayURLsFunction> playback_function(
+ new RecordReplayURLsFunction(
new TestProcessStrategy(&temp_files_)));
scoped_ptr<base::DictionaryValue> result(utils::ToDictionary(
utils::RunFunctionAndReturnSingleResult(playback_function,
@@ -217,13 +217,14 @@
// user data dir. Return via |out_list| the list of error URLs,
// if any, resulting from the capture. And return directly the
- // CaptureURLsFunction that was used, so that its state may be
+ // RecordCaptureURLsFunction that was used, so that its state may be
// queried.
« no previous file with comments | « chrome/browser/extensions/api/record/record_api.cc ('k') | chrome/browser/extensions/api/tabs/execute_code_in_tab_function.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698